==> MeUtils-2023.12.21.18.37.4.tar.gz: MeUtils-2023.12.21.18.37.4/meutils/clis/server.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : cli_fastapi
# @Time         : 2023/8/4 15:01
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 


from meutils.pipe import *


@cli.command()  # help会覆盖docstring
def celery_consumer(host='0.0.0.0', port: int = 8501):
    """
    # 消费者
    celery -A meutils.serving.celery.tasks worker -l info

    # 生产者
    mecli-server --host 127.0.0.1 --port 8000

    """

    from meutils.serving.fastapi import App
    from meutils.serving.celery.router import router

    app = App()
    app.include_router(router)
    app.run(host=host, port=port)


@cli.command()
def gunicorn_run(
        app: str,  # aiapi.views.apps:app /Users/betterme/PycharmProjects/AI/aiapi/aiapi/views/apps.py
        port: int = 8501,
        workers: int = 3,
        pythonpath: str = 'python',
        gunicorn_conf: Optional[str] = None,
        project_dir: Optional[str] = None
):
    """
    python server.py gunicorn-run aiapi.views.apps:app --project-dir /Users/betterme/PycharmProjects/AI/aiapi
    """
    project_dir = project_dir or Path(app).parent
    app = f"{Path(app).name[:-3]}:app"

    gunicorn_conf = gunicorn_conf or get_resolve_path('../serving/fastapi/gunicorn.conf.py', __file__)

    cmd = f"""
    lsof -i:{port} | grep "LISTEN" | awk '{{print $2}}' | xargs kill -9 && \
    cd {project_dir} && \
    {pythonpath} -m gunicorn -c {gunicorn_conf} \
      -k uvicorn.workers.UvicornWorker \
      --bind 0.0.0.0:{port} \
      -w {workers} \
      {app}
    """

    os.system(cmd)


if __name__ == '__main__':
    cli()

==> MeUtils-2024.1.26.8.46.12.tar.gz: MeUtils-2024.1.26.8.46.12/meutils/clis/server.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : cli_fastapi
# @Time         : 2023/8/4 15:01
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 


from meutils.pipe import *


@cli.command()  # help会覆盖docstring
def celery_consumer(host='0.0.0.0', port: int = 8501):
    """
    # 消费者
    celery -A meutils.serving.celery.tasks worker -l info

    # 生产者
    mecli-server --host 127.0.0.1 --port 8000

    """

    from meutils.serving.fastapi import App
    from meutils.serving.celery.router import router

    app = App()
    app.include_router(router)
    app.run(host=host, port=port)


@cli.command()
def gunicorn_run(
        app: str,  # aiapi.views.apps:app
        project_dir: str = './',
        port: int = 8501,
        workers: int = 3,
        pythonpath: str = 'python',
        gunicorn_conf: Optional[str] = None,
        max_requests=1000,
        max_requests_jitter=50,
):
    """
    python server.py gunicorn-run aiapi.views.apps:app --project-dir /Users/betterme/PycharmProjects/AI/aiapi
    """

    gunicorn_conf = gunicorn_conf or get_resolve_path('../serving/fastapi/gunicorn.conf.py', __file__)

    cmd = f"""
    cd {project_dir} && \
    {pythonpath} -m gunicorn -c {gunicorn_conf} \
      -k uvicorn.workers.UvicornWorker \
      --bind 0.0.0.0:{port} \
      -w {workers} \
      --max-requests {max_requests} --max-requests-jitter {max_requests_jitter} \
      {app}
    """

    rprint(cmd)

    os.system(cmd)


@cli.command()
def uvicorn_run(
        app: str,
        project_dir: str = './',
        port: int = 8501,
        workers: int = 3,
        pythonpath: str = 'python',
        reload: bool = False,
):
    """
    python server.py uvicorn-run main:app --project-dir /Users/betterme/PycharmProjects/AI/aiapi
    """

    cmd = f"""
    cd {project_dir} && \
    {pythonpath} -m uvicorn {app} \
      --host 0.0.0.0 \
      --port {port} \
      --workers {workers}
    """.strip()
    if reload:
        cmd += ' --reload'

    rprint(cmd)

    os.system(cmd)


if __name__ == '__main__':
    cli()
